[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![codecov](https://codecov.io/gh/qpv-research-group/rayflare/branch/devel/graph/badge.svg)](https://codecov.io/gh/qpv-research-group/rayflare)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/7ff9180e5f7a460192440895d823ff15)](https://www.codacy.com/gh/qpv-research-group/rayflare?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=qpv-research-group/rayflare&amp;utm_campaign=Badge_Grade)
[![Documentation Status](https://readthedocs.org/projects/rayflare/badge/?version=latest)](https://rayflare.readthedocs.io/en/latest/?badge=latest)

# rayflare
Open-source, integrated optical modelling of complex stacks. RayFlare incorporates the transfer-matrix method (TMM), 
ray-tracing and rigorous coupled-wave analysis (RCWA/FMM), in addition to an angular redistribution matrix method which allows multiple 
methods to be coupled across a single structure to calculate total absorption/reflection/transmission, absorption per 
layer, and absorption profiles. 

You can view RayFlare's documentation, including installation instructions [here](https://rayflare.readthedocs.io/en/latest/).

![poster](poster.png "RayFlare poster")
